@@ -1,28 +1,9 @@
-/** ===========================================================
- * @file
- *
- * This file is a part of KDE project
- *
- *
- * @date   2012-06-28
- * @brief  kipi host test application using KDE XML-GUI technology
- *
- * @author Copyright (C) 2012 by Victor Dodon
- *         <a href="mailto:dodonvictor at gmail dot com">dodonvictor at gmail dot com</a>
- * @author Copyright (C) 2012-2018 by Gilles Caulier
- *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
- *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * ============================================================ */
+/*
+    SPDX-FileCopyrightText: 2012 Victor Dodon <dodonvictor at gmail dot com>
+    SPDX-FileCopyrightText: 2012-2018 Gilles Caulier <caulier dot gilles at gmail dot com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kipisetup.h"
 
@@ -43,11 +24,11 @@
 #include <QStandardPaths>
 #include <QDialogButtonBox>
 
-// KDE includes
+// KF includes
 
-#include <ksharedconfig.h>
-#include <kconfiggroup.h>
-#include <kwindowconfig.h>
+#include <KSharedConfig>
+#include <KConfigGroup>
+#include <KWindowConfig>
 
 // Libkipi includes
 
@@ -71,11 +52,11 @@ class KipiSetup::Private
 public:
 
     Private() :
-        pluginFilter(0),
-        buttons(0),
-        tabView(0),
-        pluginsList(0),
-        xmlPage(0)
+        pluginFilter(nullptr),
+        buttons(nullptr),
+        tabView(nullptr),
+        pluginsList(nullptr),
+        xmlPage(nullptr)
     {
     }
 
@@ -200,7 +181,7 @@ public:
 
     Private()
     {
-        xmlFilesCob = 0;
+        xmlFilesCob = nullptr;
     }
 
     QString        uiFilesPath;
@@ -225,7 +206,7 @@ SetupXML::SetupXML(QWidget* const parent)
     d->xmlFilesCob = new QComboBox(panel);
     d->xmlFilesCob->setEditable(false);
 
-    foreach(QString uiFile, d->uiFilesList)
+    for (const QString &uiFile : std::as_const(d->uiFilesList))
     {
         d->xmlFilesCob->addItem(uiFile, uiFile);
     }
